@@ -96,8 +96,10 @@ observe({
 IRT_binary_model_rasch <- reactive({
   data <- binary()
   fit <- mirt(
-    data, model = 1, itemtype = "Rasch",
-    SE = TRUE, verbose = FALSE
+    data,
+    model = 1, itemtype = "Rasch",
+    SE = TRUE, verbose = FALSE,
+    technical = list(NCYCLES = input$ncycles)
   )
   fit
 })
@@ -111,8 +113,10 @@ IRT_binary_model_1pl <- reactive({
   )
   model <- mirt.model(s)
   fit <- mirt(
-    data, model = model, itemtype = "2PL",
-    SE = TRUE, verbose = FALSE
+    data,
+    model = model, itemtype = "2PL",
+    SE = TRUE, verbose = FALSE,
+    technical = list(NCYCLES = input$ncycles)
   )
   fit
 })
@@ -121,8 +125,10 @@ IRT_binary_model_1pl <- reactive({
 IRT_binary_model_2pl <- reactive({
   data <- binary()
   fit <- mirt(
-    data, model = 1, itemtype = "2PL",
-    SE = TRUE, verbose = FALSE
+    data,
+    model = 1, itemtype = "2PL",
+    SE = TRUE, verbose = FALSE,
+    technical = list(NCYCLES = input$ncycles)
   )
   fit
 })
@@ -131,8 +137,10 @@ IRT_binary_model_2pl <- reactive({
 IRT_binary_model_3pl <- reactive({
   data <- binary()
   fit <- mirt(
-    data, model = 1, itemtype = "3PL",
-    SE = TRUE, verbose = FALSE
+    data,
+    model = 1, itemtype = "3PL",
+    SE = TRUE, verbose = FALSE,
+    technical = list(NCYCLES = input$ncycles)
   )
   fit
 })
@@ -141,8 +149,10 @@ IRT_binary_model_3pl <- reactive({
 IRT_binary_model_4pl <- reactive({
   data <- binary()
   fit <- mirt(
-    data, model = 1, itemtype = "4PL",
-    SE = TRUE, verbose = FALSE
+    data,
+    model = 1, itemtype = "4PL",
+    SE = TRUE, verbose = FALSE,
+    technical = list(NCYCLES = input$ncycles)
   )
   fit
 })
@@ -384,11 +394,13 @@ output$IRT_binary_summary_equation_interpretation <- renderUI({
 # ** Check whether model converged ####
 output$IRT_binary_summary_model_converged <- renderUI({
   fit <- IRT_binary_model()
-  txt <- ifelse(fit@OptimInfo$converged,
+  txt <- ifelse(extract.mirt(fit, "converged"),
     "",
-    "<font color = 'orange'> Estimation process terminated without convergence.
-    Estimates are not reliable. Try to increase a number of iterations of the EM
-    algorithm in Settings. </font>"
+    paste0(
+      "<font color = 'orange'> Estimation process terminated without convergence after ",
+      extract.mirt(fit, "iterations"), " iterations. Estimates are not reliable.
+      Try to increase a number of iterations of the EM algorithm in Settings. </font>"
+    )
   )
   HTML(txt)
 })
@@ -512,6 +524,9 @@ output$IRT_binary_summary_iic_download <- downloadHandler(
 IRT_binary_summary_tic <- reactive({
   fit <- IRT_binary_model()
 
+  # TODO: use testinfo and 1 / sqrt(info)
+  # FIXME: secondary axis in plotly
+
   plt <- plot(fit, type = "infoSE")
 
   vals <- plt$panel.args
@@ -579,13 +594,17 @@ IRT_binary_summary_coef <- reactive({
     se_tab <- cbind(rep(NA, nrow(par_tab)), NA, NA, NA)
   }
 
+
   tab <- cbind(par_tab, se_tab)[, order(c(seq(ncol(par_tab)), seq(ncol(se_tab))))]
 
-  tab_fit <- itemfit(fit)[, 2:4]
-  if (!is.null(tryCatch(round(itemfit(fit)[, 2:4], 3), error = function(e) {
+  item_fit_cols <- c("S_X2", "df.S_X2", "p.S_X2")
+
+  tab_fit <- itemfit(fit, na.rm = TRUE)[, item_fit_cols]
+
+  if (!is.null(tryCatch(round(tab_fit, 3), error = function(e) {
     cat("ERROR : ", conditionMessage(e), "\n")
   }))) {
-    tab <- data.frame(tab, itemfit(fit)[, 2:4])
+    tab <- data.frame(tab, tab_fit)
     colnames(tab)[9:11] <- c("SX2-value", "df", "p-value")
   } else {
     tab <- data.frame(tab, cbind("-", "-", "-"))
@@ -625,7 +644,6 @@ output$IRT_binary_summary_coef_download <- downloadHandler(
     "tab_IRT_binary_parameters.csv"
   },
   content = function(file) {
-
     tab <- IRT_binary_summary_coef()
 
     if (input$IRT_binary_summary_parametrization == "irt") {
@@ -652,10 +670,11 @@ IRT_binary_summary_ability <- reactive({
 
   score <- as.vector(total_score())
   zscore <- as.vector(z_score())
+  tscore <- as.vector(t_score())
   fscore <- fscores(fit, full.scores.SE = TRUE)
 
-  tab <- data.frame(score, zscore, fscore)
-  colnames(tab) <- c("Total score", "Z-score", "F-score", "SE(F-score)")
+  tab <- data.frame(score, zscore, tscore, fscore)
+  colnames(tab) <- c("Total score", "Z-score", "T-score", "F-score", "SE(F-score)")
   rownames(tab) <- paste("Respondent", 1:nrow(tab))
 
   tab
@@ -690,10 +709,12 @@ IRT_binary_summary_ability_correlation <- reactive({
 })
 
 output$IRT_binary_summary_ability_correlation_text <- renderText({
-  paste0("This scatterplot shows the relationship between the standardized total
+  paste0(
+    "This scatterplot shows the relationship between the standardized total
          score (Z-score) and the factor score estimated by the IRT model. The
          Pearson correlation coefficient between these two scores is ",
-         sprintf("%.3f", IRT_binary_summary_ability_correlation()), ". ")
+    sprintf("%.3f", IRT_binary_summary_ability_correlation()), ". "
+  )
 })
 
 # ** Ability estimates plot ####
@@ -704,7 +725,7 @@ IRT_binary_summary_ability_plot <- reactive({
 
   df <- data.frame(fscore, zscore)
 
-  g <- ggplot(df, aes_string("zscore", "fscore")) +
+  g <- ggplot(df, aes(.data$zscore, .data$fscore)) +
     geom_point(size = 3) +
     labs(x = "Standardized total score", y = "Factor score") +
     theme_app()
@@ -745,8 +766,9 @@ IRT_binary_summary_wrightmap_args <- reactive({
 
   fscore <- as.vector(fscores(fit))
   b <- coef(fit, IRTpars = TRUE, simplify = TRUE)$items[, "b"]
+  item.names <- item_names()
 
-  list(fscore, b)
+  list(theta = fscore, b = b, item.names = item.names)
 })
 
 output$IRT_binary_summary_wrightmap <- renderPlotly({
@@ -767,11 +789,11 @@ output$IRT_binary_summary_wrightmap <- renderPlotly({
   txt <- paste0(txt, "<br />", thetas - binwidth, "< Theta <", thetas + binwidth)
   plt_left$x$data[[1]]$text <- txt
   plt_right <- (plts[[2]] +
-    geom_text(aes(text = paste0(
+    suppressWarnings(geom_text(aes(text = paste0(
       "Item: ",
       stringr::str_remove(item, "(\\|\\s)?0*"),
       "\n", "Difficulty: ", round(IRT_binary_summary_wrightmap_args()[[2]], 3)
-    )))) %>%
+    ))))) %>%
     ggplotly(tooltip = "text") %>%
     style(textposition = "right") %>%
     layout(yaxis = list(side = "right"))
@@ -822,11 +844,13 @@ output$IRT_binary_items_equation_interpretation <- renderUI({
 # ** Check whether model converged ####
 output$IRT_binary_items_model_converged <- renderUI({
   fit <- IRT_binary_model()
-  txt <- ifelse(fit@OptimInfo$converged,
-                "",
-                "<font color = 'orange'> Estimation process terminated without convergence.
-    Estimates are not reliable. Try to increase a number of iterations of the EM
-    algorithm in Settings. </font>"
+  txt <- ifelse(extract.mirt(fit, "converged"),
+    "",
+    paste0(
+      "<font color = 'orange'> Estimation process terminated without convergence after ",
+      extract.mirt(fit, "iterations"), " iterations. Estimates are not reliable.
+      Try to increase a number of iterations of the EM algorithm in Settings. </font>"
+    )
   )
   HTML(txt)
 })
@@ -835,19 +859,22 @@ output$IRT_binary_items_model_converged <- renderUI({
 IRT_binary_items_icc <- reactive({
   item <- input$IRT_binary_items
   fit <- IRT_binary_model()
-  n_items <- fit@Data$nitems
+  n_items <- extract.mirt(fit, "nitems")
   curve_col <- gg_color_hue(n_items)[item]
 
   d <- tibble(
     Ability = IRT_thetas_for_plots(), # vector only
-    Probability = probtrace(extract.item(fit, item),
-                            IRT_thetas_for_plots())[, 2] # ascending probs
+    Probability = probtrace(
+      extract.item(fit, item),
+      IRT_thetas_for_plots()
+    )[, 2] # ascending probs
   )
 
   g <- d %>% ggplot(aes(x = Ability, y = Probability)) +
     geom_line(color = curve_col) +
     ylab("Probability of correct answer") +
     ggtitle(item_names()[item]) +
+    ylim(0, 1) +
     theme_app()
   g
 })
@@ -893,8 +920,10 @@ IRT_binary_items_iic <- reactive({
 
   d <- tibble(
     Ability = IRT_thetas_for_plots(), # vector only
-    Information = iteminfo(extract.item(fit, item),
-                           IRT_thetas_for_plots()) # ascending probs
+    Information = iteminfo(
+      extract.item(fit, item),
+      IRT_thetas_for_plots()
+    ) # ascending probs
   )
 
   g <- d %>% ggplot(aes(x = Ability, y = Information)) +
@@ -966,27 +995,28 @@ output$IRT_binary_comparison_model_converged <- renderUI({
   fit3PL <- IRT_binary_model_3pl()
   fit4PL <- IRT_binary_model_4pl()
 
-  txt1 <- ifelse(fit1PL@OptimInfo$converged,
+  txt1 <- ifelse(extract.mirt(fit1PL, "converged"),
     "",
     "Estimation process in the <b>1PL IRT model</b> terminated without convergence. <br>"
   )
-  txt2 <- ifelse(fit2PL@OptimInfo$converged,
+  txt2 <- ifelse(extract.mirt(fit2PL, "converged"),
     "",
     "Estimation process in the <b>2PL IRT model</b> terminated without convergence. <br>"
   )
-  txt3 <- ifelse(fit3PL@OptimInfo$converged,
+  txt3 <- ifelse(extract.mirt(fit3PL, "converged"),
     "",
     "Estimation process in the <b>3PL IRT model</b> terminated without convergence. <br>"
   )
-  txt4 <- ifelse(fit4PL@OptimInfo$converged,
+  txt4 <- ifelse(extract.mirt(fit4PL, "converged"),
     "",
     "Estimation process in the <b>4PL IRT model</b> terminated without convergence. <br>"
   )
   txt <- paste0(txt1, txt2, txt3, txt4)
   if (txt != "") {
     txt <- paste0(
-    "<font color = 'orange'>", txt, "Estimates are not reliable. Try to increase
-    a number of iterations of the EM algorithm in Settings. </font>" )
+      "<font color = 'orange'>", txt, "Estimates are not reliable. Try to increase
+    a number of iterations of the EM algorithm in Settings. </font>"
+    )
   }
   HTML(txt)
 })
